==> moodle-1.6.3p0.tgz: moodle/lang/en_utf8/glossary.php <==
<?PHP // $Id: glossary.php,v 1.3 2006/04/15 19:21:36 stronk7 Exp $ 
      // glossary.php - created with Moodle 1.5 UNSTABLE DEVELOPMENT (2005010100)


$string['addcomment'] = 'Add comment';
$string['addentry'] = 'Add a new entry';
$string['addingcomment'] = 'Add a comment';
$string['aliases'] = 'Keyword(s)';
$string['allcategories'] = 'All Categories';
$string['allentries'] = 'ALL';
$string['allowcomments'] = 'Allow comments on entries';
$string['allowduplicatedentries'] = 'Duplicated entries allowed';
$string['allowprintview'] = 'Allow print view';
$string['allowratings'] = 'Allow entries to be rated?';
$string['answer'] = 'Answer';
$string['approve'] = 'Approve';
$string['areyousuredelete'] = 'Are you sure you want to delete this entry?';
$string['areyousuredeletecomment'] = 'Are you sure you want to delete this comment?';
$string['areyousureexport'] = 'Are you sure you want to export this entry to';
$string['ascending'] = '(ascending)';
$string['attachment'] = 'Attachment';
$string['authorview'] = 'Browse by Author';
$string['back'] = 'Back';
$string['cantinsertcat'] = 'Can\'t insert category';
$string['cantinsertrec'] = 'Can\'t insert record';
$string['cantinsertrel'] = 'Can\'t insert relation category-entry';
$string['casesensitive'] = 'This entry is case sensitive';
$string['categories'] = 'Categories';
$string['category'] = 'Category';
$string['categorydeleted'] = 'Category deleted';
$string['categoryview'] = 'Browse by category';
$string['cnfallowcomments'] = 'Define if a glossary will accept comments on entries by default';
$string['cnfallowdupentries'] = 'Define if a glossary will allows duplicated entries by default';
$string['cnfapprovalstatus'] = 'Define the approval status by default of an entry posted by a student';
$string['cnfcasesensitive'] = 'Define if an entry, when linked, is case sensitive by default';
$string['cnfdefaulthook'] = 'Select the default selection to show when the glossary is first viewed';
$string['cnfdefaultmode'] = 'Select the default frame to show when the glossary is first viewed.';
$string['cnffullmatch'] = 'Define if an entry, when linked, should match the case in the target text by default';
$string['cnflinkentry'] = 'Define if an entry should be automatically linked by default';
$string['cnflinkglossaries'] = 'Define if a glossary should be automatically linked by default';
$string['cnfrelatedview'] = 'Select the display format to be used for automatic linking and entry view.';
$string['cnfshowgroup'] = 'Specify if the group break should be shown or not.';
$string['cnfsortkey'] = 'Select the sorting key by default.';
$string['cnfsortorder'] = 'Select the sorting order by default.';
$string['cnfstudentcanpost'] = 'Define if the students can or cannot post entries by default';
$string['comment'] = 'Comment';
$string['commentdeleted'] = 'The comment has been deleted.';
$string['comments'] = 'Comments';
$string['commentson'] = 'Comments on';
$string['commentupdated'] = 'The comment has been updated.';
$string['concept'] = 'Concept';
$string['concepts'] = 'Concepts';
$string['configenablerssfeeds'] = 'This switch will enable the possibility of RSS feeds for all glosaries.  You will still need to turn feeds on manually in the settings for each glossary.';
$string['currentglossary'] = 'Current glossary';
$string['dateview'] = 'Browse by date';
$string['defaultapproval'] = 'Approved by default';
$string['definition'] = 'Definition';
$string['definitions'] = 'Definitions';
$string['deleteentry'] = 'Delete entry';
$string['deletingcomment'] = 'Deleting comment';
$string['deletingnoneemptycategory'] = 'Deleting this category will not delete the entries it contains - they will be marked as uncategorised.';
$string['descending'] = '(descending)';
$string['destination'] = 'Destination';
$string['displayformat'] = 'Display format';
$string['displayformatcontinuous'] = 'Continuous without author';
$string['displayformatdictionary'] = 'Simple, dictionary style';
$string['displayformatencyclopedia'] = 'Encyclopedia';
$string['displayformatentrylist'] = 'Entry list';
$string['displayformatfaq'] = 'FAQ';
$string['displayformatfullwithauthor'] = 'Full with author';
$string['displayformatfullwithoutauthor'] = 'Full without author';
$string['displayformats'] = 'Display formats';
$string['displayformatssetup'] = 'Display Formats Setup';
$string['duplicateentry'] = 'Duplicate entry';
$string['editalways'] = 'Edit always';
$string['editcategories'] = 'Edit categories';
$string['editentry'] = 'Edit entry';
$string['editingcomment'] = 'Editing comment';
$string['entbypage'] = 'Entries shown per page';
$string['entries'] = 'Entries';
$string['entrieswithoutcategory'] = 'Entries without category';
$string['entry'] = 'Entry';
$string['entryalreadyexist'] = 'Entry already exists';
$string['entryapproved'] = 'This entry has been approved';
$string['entrydeleted'] = 'Entry deleted';
$string['entryexported'] = 'Entry succesfully exported';
$string['entryishidden'] = '(this entry is currently hidden)';
$string['entryleveldefaultsettings'] = 'Entry Level Default Settings';
$string['entrysaved'] = 'This entry has been saved';
$string['entryupdated'] = 'This entry has been updated';
$string['entryusedynalink'] = 'This entry should be automatically linked';
$string['explainaddentry'] = 'Add a new entry to the current glossary.<br />Concept and definition are mandatory fields.';
$string['explainall'] = 'Shows ALL entries on one page';
$string['explainalphabet'] = 'Browse the glossary using this index';
$string['explainexport'] = 'Click on the button below to export glossary entries.<br />You can import it anytime you wish in this or other course.<p>Please note that attachments (e.g. images) and authors are not exported.</p>';
$string['explainimport'] = 'You must specify the file to import and define the criteria of the process.<p>Submit your request and review the results.</p>';
$string['explainspecial'] = 'Shows entries that do not begin with a letter';
$string['exportentries'] = 'Export entries';
$string['exportedentry'] = 'Exported entry';
$string['exportfile'] = 'Export entries to file';
$string['exportglossary'] = 'Export glossary';
$string['exporttomainglossary'] = 'Export to main glossary';
$string['filetoimport'] = 'File to import';
$string['fillfields'] = 'Concept and definition are mandatory fields.';
$string['filtername'] = 'Glossary Auto-linking';
$string['fullmatch'] = 'Match whole words only';
$string['globalglossary'] = 'Global glossary';
$string['glossaryleveldefaultsettings'] = 'Glossary Level Default Settings';
$string['glossarytype'] = 'Glossary Type';
$string['importcategories'] = 'Import categories';
$string['importedcategories'] = 'Imported categories';
$string['importedentries'] = 'Imported entries';
$string['importentries'] = 'Import entries';
$string['isglobal'] = 'Is this glossary global?';
$string['linkcategory'] = 'Automatically link this category';
$string['mainglossary'] = 'Main glossary';
$string['maxtimehaspassed'] = 'Sorry, but the maximum time for editing this comment ($a) has passed!';
$string['modulename'] = 'Glossary';
$string['modulenameplural'] = 'Glossaries';
$string['newentries'] = 'New glossary entries';
$string['newglossary'] = 'New glossary';
$string['newglossarycreated'] = 'New glossary created.';
$string['newglossaryentries'] = 'New glossary entries:';
$string['nocomment'] = 'No comment found';
$string['nocomments'] = '(No comments found on this entry)';
$string['noconceptfound'] = 'No concept or definition found.';
$string['noentries'] = 'No entries found in this section';
$string['noentry'] = 'No entry found.';
$string['notcategorised'] = 'Not categorised';
$string['numberofentries'] = 'Number of entries';
$string['onebyline'] = '(one per line)';
$string['printerfriendly'] = 'Printer-friendly version';
$string['printviewnotallowed'] = 'Print view isn\'t allowed';
$string['question'] = 'Question';
$string['rate'] = 'Rate';
$string['rating'] = 'Rating';
$string['ratingeveryone'] = 'Everyone can rate entries';
$string['ratingno'] = 'No ratings';
$string['ratingonlyteachers'] = 'Only $a can rate entries';
$string['ratings'] = 'Ratings';
$string['ratingssaved'] = 'Ratings saved';
$string['ratingsuse'] = 'Use ratings';
$string['ratingtime'] = 'Restrict ratings to entries with dates in this range:';
$string['rejectedentries'] = 'Rejected entries';
$string['rejectionrpt'] = 'Rejection Report';
$string['rsssubscriberss'] = 'Display the RSS feed for \'$a\' concepts';
$string['searchindefinition'] = 'Search full text';
$string['secondaryglossary'] = 'Secondary glossary';
$string['sendinratings'] = 'Send in my latest ratings';
$string['showall'] = 'Show \'ALL\' link';
$string['showalphabet'] = 'Show alphabet';
$string['showspecial'] = 'Show \'Special\' link';
$string['sortby'] = 'Sort by';
$string['sortbycreation'] = 'By creation date';
$string['sortbylastupdate'] = 'By last update';
$string['sortchronogically'] = 'Sort chronologically';
$string['special'] = 'Special';
$string['standardview'] = 'Browse by alphabet';
$string['studentcanpost'] = 'Students can add entries';
$string['totalentries'] = 'Total entries';
$string['usedynalink'] = 'Automatically link glossary entries';
$string['waitingapproval'] = 'Waiting approval';
$string['warningstudentcapost'] = '(Applies only if the glossary is not the main one)';
$string['withauthor'] = 'Concepts with author';
$string['withoutauthor'] = 'Concepts without author';
$string['writtenby'] = 'by';
$string['youarenottheauthor'] = 'You are not the author of this comment, so you are not allowed to edit it.';

?>

==> moodle-1.9.16.tgz: moodle/lang/en_utf8/glossary.php <==
<?PHP // $Id: glossary.php,v 1.8.2.6 2011/02/17 00:44:14 moodlerobot Exp $
      // glossary.php - created with Moodle 1.7 beta + (2006101003)


$string['addcomment'] = 'Add comment';
$string['addentry'] = 'Add a new entry';
$string['addingcomment'] = 'Add a comment';
$string['aliases'] = 'Keyword(s)';
$string['allcategories'] = 'All Categories';
$string['allentries'] = 'ALL';
$string['allowcomments'] = 'Allow comments on entries';
$string['allowduplicatedentries'] = 'Duplicated entries allowed';
$string['allowprintview'] = 'Allow print view';
$string['allowratings'] = 'Allow entries to be rated?';
$string['andmorenewentries'] = 'and {$a} more new entries.';
$string['answer'] = 'Answer';
$string['approve'] = 'Approve';
$string['areyousuredelete'] = 'Are you sure you want to delete this entry?';
$string['areyousuredeletecomment'] = 'Are you sure you want to delete this comment?';
$string['areyousureexport'] = 'Are you sure you want to export this entry to';
$string['ascending'] = 'ascending';
$string['attachment'] = 'Attachment';
$string['author'] = 'author';
$string['authorview'] = 'Browse by Author';
$string['back'] = 'Back';
$string['cantinsertcat'] = 'Can\'t insert category';
$string['cantinsertrec'] = 'Can\'t insert record';
$string['cantinsertrel'] = 'Can\'t insert relation category-entry';
$string['casesensitive'] = 'This entry is case sensitive';
$string['cat'] = 'cat';
$string['categories'] = 'Categories';
$string['category'] = 'Category';
$string['categorydeleted'] = 'Category deleted';
$string['categoryview'] = 'Browse by category';
$string['cnfallowcomments'] = 'Define if a glossary will accept comments on entries by default';
$string['cnfallowdupentries'] = 'Define if a glossary will allows duplicated entries by default';
$string['cnfapprovalstatus'] = 'Define the approval status by default of an entry posted by a student';
$string['cnfcasesensitive'] = 'Define if an entry, when linked, is case sensitive by default';
$string['cnfdefaulthook'] = 'Select the default selection to show when the glossary is first viewed';
$string['cnfdefaultmode'] = 'Select the default frame to show when the glossary is first viewed.';
$string['cnffullmatch'] = 'Define if an entry, when linked, should match the case in the target text by default';
$string['cnflinkentry'] = 'Define if an entry should be automatically linked by default';
$string['cnflinkglossaries'] = 'Define if a glossary should be automatically linked by default';
$string['cnfrelatedview'] = 'Select the display format to be used for automatic linking and entry view.';
$string['cnfshowgroup'] = 'Specify if the group break should be shown or not.';
$string['cnfsortkey'] = 'Select the sorting key by default.';
$string['cnfsortorder'] = 'Select the sorting order by default.';
$string['cnfstudentcanpost'] = 'Define if the students can or cannot post entries by default';
$string['comment'] = 'Comment';
$string['commentdeleted'] = 'The comment has been deleted.';
$string['comments'] = 'Comments';
$string['commentson'] = 'Comments on';
$string['commentupdated'] = 'The comment has been updated.';
$string['concept'] = 'Concept';
$string['concepts'] = 'Concepts';
$string['configenablerssfeeds'] = 'This switch will enable the possibility of RSS feeds for all glossaries.  You will still need to turn feeds on manually in the settings for each glossary.';
$string['currentglossary'] = 'Current glossary';
$string['changeto'] = 'change to $a';
$string['current']= 'Currently sorted $a';
$string['errconceptalreadyexists'] = 'This concept already exists. No duplicates allowed in this glossary.';
$string['erredittimeexpired'] = 'The editing time for this entry has expired.';
$string['errcannoteditothers'] = 'You cannot edit other people\'s entries.';
$string['date'] = 'date';
$string['dateview'] = 'Browse by date';
$string['defaultapproval'] = 'Approved by default';
$string['defaulthook'] = 'Default hook';
$string['defaultmode'] = 'Default mode';
$string['defaultsortkey'] = 'Default sort key';
$string['defaultsortorder'] = 'Default sort order';
$string['definition'] = 'Definition';
$string['definitions'] = 'Definitions';
$string['deleteentry'] = 'Delete entry';
$string['deletenotenrolled'] = 'Delete entries by users not enrolled';
$string['deletingcomment'] = 'Deleting comment';
$string['deletingnoneemptycategory'] = 'Deleting this category will not delete the entries it contains - they will be marked as uncategorised.';
$string['descending'] = 'descending';
$string['destination'] = 'Destination';
$string['displayformat'] = 'Display format';
$string['displayformatcontinuous'] = 'Continuous without author';
$string['displayformatdictionary'] = 'Simple, dictionary style';
$string['displayformatencyclopedia'] = 'Encyclopedia';
$string['displayformatentrylist'] = 'Entry list';
$string['displayformatfaq'] = 'FAQ';
$string['displayformatfullwithauthor'] = 'Full with author';
$string['displayformatfullwithoutauthor'] = 'Full without author';
$string['displayformats'] = 'Display formats';
$string['displayformatssetup'] = 'Display Formats Setup';
$string['duplicateentry'] = 'Duplicate entry';
$string['editalways'] = 'Edit always';
$string['editcategories'] = 'Edit categories';
$string['editentry'] = 'Edit entry';
$string['editingcomment'] = 'Editing comment';
$string['entbypage'] = 'Entries shown per page';
$string['entries'] = 'Entries';
$string['entrieswithoutcategory'] = 'Entries without category';
$string['entry'] = 'Entry';
$string['entryalreadyexist'] = 'Entry already exists';
$string['entryapproved'] = 'This entry has been approved';
$string['entrydeleted'] = 'Entry deleted';
$string['entryexported'] = 'Entry succesfully exported';
$string['entryishidden'] = '(this entry is currently hidden)';
$string['entryleveldefaultsettings'] = 'Entry Level Default Settings';
$string['entrysaved'] = 'This entry has been saved';
$string['entryupdated'] = 'This entry has been updated';
$string['entryusedynalink'] = 'This entry should be automatically linked';
$string['errorparsingxml'] = 'Errors occurred while parsing the file. Make sure it is valid XML syntax.';
$string['explainaddentry'] = 'Add a new entry to the current glossary.<br />Concept and definition are mandatory fields.';
$string['explainall'] = 'Shows ALL entries on one page';
$string['explainalphabet'] = 'Browse the glossary using this index';
$string['explainexport'] = 'Click on the button below to export glossary entries.<br />You can import it anytime you wish in this or other course.<p>Please note that attachments (e.g. images) and authors are not exported.</p>';
$string['explainimport'] = 'You must specify the file to import and define the criteria of the process.<p>Submit your request and review the results.</p>';
$string['explainspecial'] = 'Shows entries that do not begin with a letter';
$string['exportedentry'] = 'Exported entry';
$string['exportentries'] = 'Export entries';
$string['exportentriestoxml'] = 'Export entries to XML file';
$string['exportfile'] = 'Export entries to file';
$string['exportglossary'] = 'Export glossary';
$string['exporttomainglossary'] = 'Export to main glossary';
$string['filetoimport'] = 'File to import';
$string['fillfields'] = 'Concept and definition are mandatory fields.';
$string['filtername'] = 'Glossary Auto-linking';
$string['fullmatch'] = 'Match whole words only';
$string['globalglossary'] = 'Global glossary';
$string['glossary:approve'] = 'Approve unapproved entries';
$string['glossary:comment'] = 'Create comments';
$string['glossary:export'] = 'Export entries';
$string['glossary:import'] = 'Import entries';
$string['glossary:managecategories'] = 'Manage categories';
$string['glossary:managecomments'] = 'Manage comments';
$string['glossary:manageentries'] = 'Manage entries';
$string['glossary:rate'] = 'Rate entries';
$string['glossary:view'] = 'View glossary';
$string['glossary:viewrating'] = 'View ratings';
$string['glossary:write'] = 'Create new entries';
$string['glossaryleveldefaultsettings'] = 'Glossary Level Default Settings';
$string['glossarytype'] = 'Glossary Type';
$string['importcategories'] = 'Import categories';
$string['importedcategories'] = 'Imported categories';
$string['importedentries'] = 'Imported entries';
$string['importentries'] = 'Import entries';
$string['importentriesfromxml'] = 'Import entries from XML file';
$string['includegroupbreaks'] = 'Include group breaks';
$string['invalidrate'] = 'Invalid glossary rate ($a)';
$string['isglobal'] = 'Is this glossary global?';
$string['letter'] = 'letter';
$string['linkcategory'] = 'Automatically link this category';
$string['linking'] = 'Auto-linking';
$string['mainglossary'] = 'Main glossary';
$string['maxtimehaspassed'] = 'Sorry, but the maximum time for editing this comment ($a) has passed!';
$string['modulename'] = 'Glossary';
$string['modulenameplural'] = 'Glossaries';
$string['newentries'] = 'New glossary entries';
$string['newglossary'] = 'New glossary';
$string['newglossarycreated'] = 'New glossary created.';
$string['newglossaryentries'] = 'New glossary entries:';
$string['nocomment'] = 'No comment found';
$string['nocomments'] = '(No comments found on this entry)';
$string['noconceptfound'] = 'No concept or definition found.';
$string['noentries'] = 'No entries found in this section';
$string['noentry'] = 'No entry found.';
$string['notcategorised'] = 'Not categorised';
$string['numberofentries'] = 'Number of entries';
$string['onebyline'] = '(one per line)';
$string['popupformat'] = 'Popup format';
$string['printerfriendly'] = 'Printer-friendly version';
$string['printviewnotallowed'] = 'Print view isn\'t allowed';
$string['resetglossariesall'] = 'Delete entries from all glossaries';
$string['resetglossaries'] = 'Delete entries from';
$string['question'] = 'Question';
$string['rate'] = 'Rate';
$string['rating'] = 'Rating';
$string['ratingeveryone'] = 'Everyone can rate entries';
$string['ratingno'] = 'No ratings';
$string['ratingonlyteachers'] = 'Only $a can rate entries';
$string['ratings'] = 'Ratings';
$string['ratingssaved'] = 'Ratings saved';
$string['ratingsuse'] = 'Use ratings';
$string['ratingtime'] = 'Restrict ratings to entries with dates in this range:';
$string['rejectedentries'] = 'Rejected entries';
$string['rejectionrpt'] = 'Rejection Report';
$string['rsssubscriberss'] = 'Display the RSS feed for \'$a\' concepts';
$string['searchindefinition'] = 'Search full text';
$string['secondaryglossary'] = 'Secondary glossary';
$string['sendinratings'] = 'Send in my latest ratings';
$string['showall'] = 'Show \'ALL\' link';
$string['showalphabet'] = 'Show alphabet';
$string['showspecial'] = 'Show \'Special\' link';
$string['sortby'] = 'Sort by';
$string['sortbycreation'] = 'By creation date';
$string['sortbylastupdate'] = 'By last update';
$string['sortchronogically'] = 'Sort chronologically';
$string['special'] = 'Special';
$string['standardview'] = 'Browse by alphabet';
$string['studentcanpost'] = 'Students can add entries';
$string['totalentries'] = 'Total entries';
$string['usedynalink'] = 'Automatically link glossary entries';
$string['waitingapproval'] = 'Waiting approval';
$string['warningstudentcapost'] = '(Applies only if the glossary is not the main one)';
$string['withauthor'] = 'Concepts with author';
$string['withoutauthor'] = 'Concepts without author';
$string['writtenby'] = 'by';
$string['youarenottheauthor'] = 'You are not the author of this comment, so you are not allowed to edit it.';

?>
